==> nextcloud-app-spreed-1%3A6.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/el.js <==
OC.L10N.register(
    "spreed",
    {
    "{name} (public)" : "{name} (δημόσιο)",
    "New conversation …" : "Νέα συζήτηση …",
    "Participants" : "Συμμετέχοντες",
    "Chat" : "Συνομιλία",
    "Exit fullscreen (f)" : "Έξοδος πλήρους οθόνης (f)",
    "Fullscreen (f)" : "Πλήρης οθόνη (f)",
    "Copy" : "Αντιγραφή",
    "Copied!" : "Αντιγράφτηκε!",
    "Not supported!" : "Δεν υποστηρίζεται!",
    "Press ⌘-C to copy." : "Για αντιγραφή πατήστε ⌘-C.",
    "Press Ctrl-C to copy." : "Για αντιγραφή πατήστε Ctrl-C.",
    "Password required" : "Απαιτείται συνθηματικό",
    "Password" : "Συνθηματικό",
    "Cancel" : "Ακύρωση",
    "Submit" : "Υποβολή",
    "Leave call" : "Αποχώρηση από την κλήση",
    "Share link" : "Διαμοιρασμός συνδέσμου",
    "Change password" : "Αλλαγή συνθηματικού",
    "Set password" : "Ορισμός συνθηματικού",
    "Name" : "Όνομα",
    "Rename" : "Μετονομασία",
    "Copy link" : "Αντιγραφή συνδέσμου",
    "You" : "Εσείς",
    "New message …" : "Νέο μήνυμα …",
    "Send" : "Αποστολή",
    "Guest" : "Επισκέπτης",
    "Yesterday" : "Χθες",
    "Edit" : "Επεξεργασία",
    "No other people in this call" : "Κανένα άλλο άτομο σε αυτή την κλήση",
    "Waiting for {participantName} to join the call …" : "Αναμονή για είσοδο στην κλήση του {participantName} ...",
    "Waiting for others to join the call …" : "Αναμονή για είσοδο υπόλοιπων στην κλήση ...",
    "Share this link to invite others!" : "Διαμοιρασμός του συνδέσμου για να προσκαλέσετε άλλους!",
    "WebRTC is not supported in your browser :-/" : "Το WebRTC δεν υποστηρίζεται από τον φυλλομετρητή σας :-/",
    "Please use a different browser like Firefox or Chrome" : "Παρακαλούμε χρησιμοποιήστε διαφορετικό φυλλομετρητή όπως ο Firefox ή Chrome",
    "Waiting for camera and microphone permissions" : "Αναμονή για δικαιώματα για την κάμερα και το μικρόφωνο",
    "Please, give your browser access to use your camera and microphone in order to use this app." : "Παρακαλούμε δώστε πρόσβαση στον φυλλομετρητή να χρησιμοποιήσει την κάμερα και το μικρόφωνο ώστε να χρησιμοποιήσετε αυτή την εφαρμογή.",
    "Disable video" : "Απενεργοποίηση βίντεο",
    "Share screen" : "Διαμοιρασμός οθόνης",
    "Show your screen" : "Εμφάνιση της οθόνης σας",
    "Stop screensharing" : "Διακόψτε την κοινή χρήση της οθόνης",
    "Mute audio (m)" : "Σίγαση ήχου (m)",
    "Disable video (v)" : "Απενεργοποίηση βίντεο (v)",
    "Screensharing is not supported by your browser." : "Ο διαμοιρασμός της οθόνης δεν υποστηρίζεται από τον φυλλομετρητή σας.",
    "Screensharing requires the page to be loaded through HTTPS." : "Για τον διαμοιρασμό οθόνης απαιτείται η φόρτωση της σελίδας μέσω HTTPS.",
    "Screensharing options" : "Επιλογές διαμοιρασμού οθόνης",
    "Sharing your screen only works with Firefox version 52 or newer." : "Η κοινή χρήση της οθόνης σας λειτουργεί μόνο με την έκδοση Firefox 52 ή νεότερη.",
    "Screensharing extension is required to share your screen." : "Το πρόσθετο διαμοιρασμού οθόνης απαιτείται για να διαμοιράσετε την οθόνη σας.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Παρακαλώ χρησιμοποιήστε διαφορετικό φυλλομετρητή όπως ο Firefox ή ο Chrome για να διαμοιάσετε την οθόνη σας.",
    "An error occurred while starting screensharing." : "Προυσιάστηκε σφάλμα κατά την έναρξη του διαμοιρασμού οθόνης.",
    "Enable screensharing" : "Ενεργοποίηση διαμοιρασμού οθόνης",
    "Add participant …" : "Προσθήκη συμμετέχοντα …",
    "Your screen" : "Η οθόνη σας",
    "Guest's screen" : "Η οθόνη του επισκέπτη",
    "Close" : "Κλείσιμο",
    "Show screen" : "Εμφάνιση οθόνης",
    "Access to microphone & camera is only possible with HTTPS" : "Η πρόσβαση στο μικρόφωνο και στην κάμερα είναι εφικτή μόνο μέσω HTTPS",
    "Access to microphone & camera was denied" : "Άρνηση πρόσβασης στο μικρόφωνο & την κάμερα",
    "WebRTC is not supported in your browser" : "Το WebRTC δεν υποστηρίζεται από τον φυλλομετρητή σας",
    "Error while accessing microphone & camera" : "Σφάλμα κατά την πρόσβαση στο μικρόφωνο & την κάμερα",
    "_%n guest_::_%n guests_" : ["%n επισκέπτης","%n επισκέπτες"],
    "{user} wants to talk with you" : "Ο {user} θέλει να σας μιλήσει",
    "Validate SSL certificate" : "Επικυρώστε το πιστοποιητικό SSL",
    "TURN server protocols" : "Πρωτόκολλα διακομιστή TURN",
    "UDP and TCP" : "UDP και TCP",
    "UDP only" : "Μόνο UDP",
    "TCP only" : "Μόνο TCP",
    "Saved" : "Αποθηκεύτηκαν",
    "Shared secret" : "Διαμοιρασμένο μυστικό",
    "STUN servers" : "Διακομιστές STUN",
    "TURN server" : "Διακομιστής TURN",
    "Android app" : "Εφαρμογή Android",
    "iOS app" : "Εφαρμογή iOS",
    "Delete server" : "Διαγραφή διακομιστή",
    "Add new server" : "Προσθήκη νέου διακομιστή",
    "New public conversation" : "Νέα δημόσια συνομιλία",
    "New group conversation" : "Νέα ομαδική συζήτηση",
    "_%n other guest_::_%n other guests_" : ["%n επισκέπτης","%n επισκέπτες"],
    ", " : ", "
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-spreed-1%3A7.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/el.js <==
OC.L10N.register(
    "spreed",
    {
    "_%n guest_::_%n guests_" : ["%n επισκέπτης","%n επισκέπτες"],
    "Guest" : "Επισκέπτης",
    "Private conversation" : "Ιδιωτική συνομιλία",
    "{user} wants to talk with you" : "Ο {user} θέλει να σας μιλήσει",
    "Everyone" : "Όλοι",
    "Moderators" : "Συντονιστές",
    "Users" : "Χρήστες",
    "Validate SSL certificate" : "Επικυρώστε το πιστοποιητικό SSL",
    "TURN server protocols" : "Πρωτόκολλα διακομιστή TURN",
    "UDP and TCP" : "UDP και TCP",
    "UDP only" : "Μόνο UDP",
    "TCP only" : "Μόνο TCP",
    "Copy link" : "Αντιγραφή συνδέσμου",
    "Share link" : "Διαμοιρασμός συνδέσμου",
    "Participants" : "Συμμετέχοντες",
    "Commands" : "Εντολές",
    "Name" : "Όνομα",
    "Saved" : "Αποθηκεύτηκαν",
    "Shared secret" : "Διαμοιρασμένο μυστικό",
    "STUN servers" : "Διακομιστές STUN",
    "Password" : "Συνθηματικό",
    "Fullscreen (f)" : "Πλήρης οθόνη (f)",
    "Specify commands the users can use in chats" : "Καθορίστε τις εντολές που μπορούν να χρησιμοποιήσουν οι χρήστες στις συνομιλίες",
    "TURN server" : "Διακομιστής TURN",
    "Android app" : "Εφαρμογή Android",
    "iOS app" : "Εφαρμογή iOS",
    "Delete server" : "Διαγραφή διακομιστή",
    "Add new server" : "Προσθήκη νέου διακομιστή",
    "New public conversation" : "Νέα δημόσια συνομιλία",
    "New group conversation" : "Νέα ομαδική συζήτηση",
    "{name} (public)" : "{name} (δημόσιο)",
    "New conversation …" : "Νέα συζήτηση …",
    "Chat" : "Συνομιλία",
    "Exit fullscreen (f)" : "Έξοδος πλήρους οθόνης (f)",
    "Copy" : "Αντιγραφή",
    "Copied!" : "Αντιγράφτηκε!",
    "Not supported!" : "Δεν υποστηρίζεται!",
    "Press ⌘-C to copy." : "Για αντιγραφή πατήστε ⌘-C.",
    "Press Ctrl-C to copy." : "Για αντιγραφή πατήστε Ctrl-C.",
    "Password required" : "Απαιτείται συνθηματικό",
    "Cancel" : "Ακύρωση",
    "Submit" : "Υποβολή",
    "Leave call" : "Αποχώρηση από την κλήση",
    "Change password" : "Αλλαγή συνθηματικού",
    "Set password" : "Ορισμός συνθηματικού",
    "Rename" : "Μετονομασία",
    "You" : "Εσείς",
    "New message …" : "Νέο μήνυμα …",
    "Send" : "Αποστολή",
    "Yesterday" : "Χθες",
    "Edit" : "Επεξεργασία",
    "No other people in this call" : "Κανένα άλλο άτομο σε αυτή την κλήση",
    "Waiting for {participantName} to join the call …" : "Αναμονή για είσοδο στην κλήση του {participantName} ...",
    "Waiting for others to join the call …" : "Αναμονή για είσοδο υπόλοιπων στην κλήση ...",
    "Share this link to invite others!" : "Διαμοιρασμός του συνδέσμου για να προσκαλέσετε άλλους!",
    "WebRTC is not supported in your browser :-/" : "Το WebRTC δεν υποστηρίζεται από τον φυλλομετρητή σας :-/",
    "Please use a different browser like Firefox or Chrome" : "Παρακαλούμε χρησιμοποιήστε διαφορετικό φυλλομετρητή όπως ο Firefox ή Chrome",
    "Waiting for camera and microphone permissions" : "Αναμονή για δικαιώματα για την κάμερα και το μικρόφωνο",
    "Please, give your browser access to use your camera and microphone in order to use this app." : "Παρακαλούμε δώστε πρόσβαση στον φυλλομετρητή να χρησιμοποιήσει την κάμερα και το μικρόφωνο ώστε να χρησιμοποιήσετε αυτή την εφαρμογή.",
    "Disable video" : "Απενεργοποίηση βίντεο",
    "Share screen" : "Διαμοιρασμός οθόνης",
    "Show your screen" : "Εμφάνιση της οθόνης σας",
    "Stop screensharing" : "Διακόψτε την κοινή χρήση της οθόνης",
    "Mute audio (m)" : "Σίγαση ήχου (m)",
    "Disable video (v)" : "Απενεργοποίηση βίντεο (v)",
    "Screensharing is not supported by your browser." : "Ο διαμοιρασμός της οθόνης δεν υποστηρίζεται από τον φυλλομετρητή σας.",
    "Screensharing requires the page to be loaded through HTTPS." : "Για τον διαμοιρασμό οθόνης απαιτείται η φόρτωση της σελίδας μέσω HTTPS.",
    "Screensharing options" : "Επιλογές διαμοιρασμού οθόνης",
    "Sharing your screen only works with Firefox version 52 or newer." : "Η κοινή χρήση της οθόνης σας λειτουργεί μόνο με την έκδοση Firefox 52 ή νεότερη.",
    "Screensharing extension is required to share your screen." : "Το πρόσθετο διαμοιρασμού οθόνης απαιτείται για να διαμοιράσετε την οθόνη σας.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Παρακαλώ χρησιμοποιήστε διαφορετικό φυλλομετρητή όπως ο Firefox ή ο Chrome για να διαμοιάσετε την οθόνη σας.",
    "An error occurred while starting screensharing." : "Προυσιάστηκε σφάλμα κατά την έναρξη του διαμοιρασμού οθόνης.",
    "Enable screensharing" : "Ενεργοποίηση διαμοιρασμού οθόνης",
    "Add participant …" : "Προσθήκη συμμετέχοντα …",
    "Close" : "Κλείσιμο",
    "Show screen" : "Εμφάνιση οθόνης",
    "Access to microphone & camera is only possible with HTTPS" : "Η πρόσβαση στο μικρόφωνο και στην κάμερα είναι εφικτή μόνο μέσω HTTPS",
    "Access to microphone & camera was denied" : "Άρνηση πρόσβασης στο μικρόφωνο & την κάμερα",
    "WebRTC is not supported in your browser" : "Το WebRTC δεν υποστηρίζεται από τον φυλλομετρητή σας",
    "Error while accessing microphone & camera" : "Σφάλμα κατά την πρόσβαση στο μικρόφωνο & την κάμερα",
    "Guest's screen" : "Η οθόνη του επισκέπτη",
    "Your screen" : "Η οθόνη σας",
    "_%n other guest_::_%n other guests_" : ["%n επισκέπτης","%n επισκέπτες"],
    ", " : ", ",
    "Unnamed conversation" : "Ανώνυμη συνομιλία"
},
"nplurals=2; plural=(n != 1);");
